geoserver

package
v0.0.0-...-212e11a Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 2, 2025 License: MPL-2.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CreateConfig

func CreateConfig(URL string,
	GwcURL string,
	Username string,
	Password string,
	InsecureSkipVerify bool) (interface{}, error)

func Provider

func Provider() terraform.ResourceProvider

Provider returns a terraform.ResourceProvider.

Types

type Config

type Config struct {
	URL                string
	GwcURL             string
	Username           string
	Password           string
	InsecureSkipVerify bool
}

Config is the configuration parameters for the Geoserver

func (*Config) GeoserverClient

func (c *Config) GeoserverClient() *gs.Client

GeoserverClient creates a Geoserver client scoped to the global API

func (*Config) GwcClient

func (c *Config) GwcClient() *gs.Client

Client creates a Geoserver client scoped to the global API

Jump to